import * as React from 'react';
import { Grid, Container, Breadcrumb, Header, Menu, Input, Segment } from 'semantic-ui-react';


export interface StateProps {
  sub: any;
  title: any;
}

export interface DispatchProps {
  onRedirect(path: string): void;
}

export type Props = StateProps & DispatchProps;

export interface State {
  selected: number;
}

export class TitleBar extends React.Component<Props, State> {

  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
      selected: 0,
    };
  }

  public handleMenu(menu: any, index: number): any {
    this.setState({
      selected: index,
    });
    if (this.state.selected !== index) {
      this.props.onRedirect(menu.path);
    }
  }

  public renderSubMenus(): JSX.Element {
    let subMenus = this.props.sub;
    if (!subMenus) {
      return null;
    }

    return subMenus.map((menu: any, index: number) => (
      <Menu.Item key={index} name={menu.name} onClick={this.handleMenu.bind(this, menu, index)} active={this.state.selected === index} />
    ));
  }

  public render(): JSX.Element {
    return (
      <Menu fluid style={{ 'borderLeft': '0px', 'borderRight': '0px', 'boxShadow': 'none', 'borderRadius': '0' }}>
        <Menu.Item style={{ width: '250px' }}>
          <Header as='h3'>{this.props.title}
            <Header.Subheader>
              <Breadcrumb size='mini'>
                <Breadcrumb.Section link>Home</Breadcrumb.Section>
                <Breadcrumb.Divider />
                <Breadcrumb.Section link>Monitoring</Breadcrumb.Section>
                <Breadcrumb.Divider />
                <Breadcrumb.Section active>Probes</Breadcrumb.Section>
              </Breadcrumb>
            </Header.Subheader>
          </Header>
        </Menu.Item>
        {this.renderSubMenus()}
      </Menu>
    );
  }
}



