import Action from './Action';
import * as Redux from 'redux';

interface ReducerItem<State> {
  initialState: State;
  reducer: Redux.Reducer<State>;
}

class ReducerManager {
  private reducerMap: Map<string, ReducerItem<any>[]>;

  public constructor() {
    this.reducerMap = new Map();
  }

  public putReducer<State>(type: string, initialState: State, reducer: Redux.Reducer<State>): void {
    let reducerItems: ReducerItem<any>[];
    if (!this.reducerMap.has(type)) {
      reducerItems = new Array();
      this.reducerMap.set(type, reducerItems);
    } else {
      reducerItems = this.reducerMap.get(type);
    }
    let reducerItem: ReducerItem<State> = {
      initialState: initialState,
      reducer: reducer,
    };

    reducerItems.push(reducerItem);
  }

  public putReducers<State>(initialState: State, handlers: Redux.ReducersMapObject): void {
    for(let type in handlers) {
      if (handlers.hasOwnProperty(type)) {
        this.putReducer(type, initialState, handlers[type]);
      }
    }
  }

  public reducer<State, A extends Action>(state: State, action: A): State {
    const actionType = action.type;
    if (this.reducerMap.has(actionType)) {
      let reducerItems = this.reducerMap.get(actionType);
      for (let reducerItem of reducerItems) {
        let initialState = reducerItem.initialState;
        let reducer = reducerItem.reducer;
        state = reducer(state, action);
      }
    } else {
      console.log(`Reducer for [${actionType}] is not loaded.`);
    }
    return state;
  }
}

export default ReducerManager;
